import { Action } from '@ngrx/store';
import { schema } from 'normalizr';
import { EntityMap } from '../reducers/normalize';
export interface SchemaMap {
    [schemaKey: string]: string;
}
export interface NormalizeActionPayload {
    entities: EntityMap;
    result: string[];
}
export interface NormalizeRemoveActionPayload {
    id: string;
    key: string;
    removeChildren: SchemaMap | null;
}
export interface NormalizeActionSchemaConfig {
    schema: schema.Entity;
}
export interface NormalizeActionConfig<T> extends NormalizeActionSchemaConfig {
    data: T[];
}
export interface NormalizeRemoveActionConfig extends NormalizeActionSchemaConfig {
    id: NormalizeRemoveActionPayload['id'];
    removeChildren?: NormalizeRemoveActionPayload['removeChildren'];
}
export interface NormalizeActionCreators<T> {
    setData: (data: T[]) => SetData<T>;
    addData: (data: T[]) => AddData<T>;
    removeData: (id: string, removeChildren?: SchemaMap) => RemoveData;
}
export declare class NormalizeActionTypes {
    static readonly SET_DATA: string;
    static readonly ADD_DATA: string;
    static readonly REMOVE_DATA: string;
}
export declare class SetData<T> implements Action {
    readonly type: string;
    payload: NormalizeActionPayload;
    constructor(config: NormalizeActionConfig<T>);
}
export declare class AddData<T> implements Action {
    readonly type: string;
    payload: NormalizeActionPayload;
    constructor(config: NormalizeActionConfig<T>);
}
export declare class RemoveData implements Action {
    readonly type: string;
    payload: NormalizeRemoveActionPayload;
    constructor(config: NormalizeRemoveActionConfig);
}
export declare function actionCreators<T>(schema: schema.Entity): NormalizeActionCreators<T>;
