"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var normalizr_1 = require("normalizr");
var ACTION_NAMESPACE = '[@@Normalize]';
var NormalizeActionTypes = (function () {
    function NormalizeActionTypes() {
    }
    NormalizeActionTypes.SET_DATA = ACTION_NAMESPACE + " Set Data";
    NormalizeActionTypes.ADD_DATA = ACTION_NAMESPACE + " Add Data";
    NormalizeActionTypes.REMOVE_DATA = ACTION_NAMESPACE + " Remove Data";
    return NormalizeActionTypes;
}());
exports.NormalizeActionTypes = NormalizeActionTypes;
var SetData = (function () {
    function SetData(config) {
        this.type = NormalizeActionTypes.SET_DATA;
        this.payload = normalizr_1.normalize(config.data, [config.schema]);
    }
    return SetData;
}());
exports.SetData = SetData;
var AddData = (function () {
    function AddData(config) {
        this.type = NormalizeActionTypes.ADD_DATA;
        this.payload = normalizr_1.normalize(config.data, [config.schema]);
    }
    return AddData;
}());
exports.AddData = AddData;
var RemoveData = (function () {
    function RemoveData(config) {
        this.type = NormalizeActionTypes.REMOVE_DATA;
        var id = config.id, removeChildren = config.removeChildren, schema = config.schema;
        var removeMap = null;
        if (removeChildren && schema.schema) {
            removeMap = Object.entries(removeChildren).reduce(function (p, _a) {
                var key = _a[0], entityProperty = _a[1];
                if (entityProperty in schema.schema) {
                    p[key] = entityProperty;
                }
                return p;
            }, {});
        }
        this.payload = {
            id: id,
            key: schema.key,
            removeChildren: removeMap && Object.keys(removeMap).length ? removeMap : null
        };
    }
    return RemoveData;
}());
exports.RemoveData = RemoveData;
function actionCreators(schema) {
    return {
        setData: function (data) {
            return new SetData({ data: data, schema: schema });
        },
        addData: function (data) {
            return new AddData({ data: data, schema: schema });
        },
        removeData: function (id, removeChildren) { return new RemoveData({ id: id, schema: schema, removeChildren: removeChildren }); }
    };
}
exports.actionCreators = actionCreators;
